JoinedMessage class final

Concatenate the text of multiple Message instances together. If separator is not null, it's localized value will be inserted between each element.

Inheritance
Implemented types

Constructors

JoinedMessage(List<Message> parts, {Message? separator})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
parts List<Message>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator Message?
final

Methods

get(BuildContext context) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) String
Retrieve the localized string for the given context
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited