Localized class

Creates a Text widget showing the translation of text for the current context's language.

Inheritance
Annotations

Constructors

Localized({Key? key, required Message text, TextStyle? style, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, TextScaler? textScaler, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale Locale?
The value to be passed to Text.locale
final
maxLines int?
The value to be passed to Text.maxLines
final
overflow TextOverflow?
The value to be passed to Text.overflow
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionColor Color?
The value to be passed to Text.selectionColor
final
semanticsLabel String?
The value to be passed to Text.semanticsLabel
final
softWrap bool?
The value to be passed to Text.softWrap
final
strutStyle StrutStyle?
The value to be passed to Text.strutStyle
final
style TextStyle?
The value to be passed to Text.style
final
text Message
The getter for the text to display
final
textAlign TextAlign?
The value to be passed to Text.textAlign
final
textDirection TextDirection?
The value to be passed to Text.textDirection
final
textHeightBehavior TextHeightBehavior?
The value to be passed to Text.textHeightBehavior
final
textScaler TextScaler?
The value to be passed to Text.textScaler
final
textWidthBasis TextWidthBasis?
The value to be passed to Text.textWidthBasis
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited