LocalizedText class abstract

Implemented types
Implementers
Annotations

Constructors

LocalizedText()
const
LocalizedText.fallback(String? text, LocalizedText fallback)
If the given text is null, it falls back to the provided fallback instance.
factory
LocalizedText.joined(List<Message> parts, {Message? separator})
const
factory
LocalizedText.static(String text)
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(BuildContext context) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) String
Retrieve the localized string for the given context
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited