Message.static constructor
const
Message.static(
- String text
Returns the value of text regardless of the current locale.
Implementation
const factory Message.static(String text) = StaticMessage;
Returns the value of text regardless of the current locale.
const factory Message.static(String text) = StaticMessage;