NumberFormatType class sealed

Constructors

NumberFormatType.compact({bool long, bool explicitSign})
const
factory
NumberFormatType.currency({bool compact, String? name, String? symbol, int? decimalDigits})
const
factory
NumberFormatType.custom([String? pattern])
const
factory
NumberFormatType.decimal({int? decimalDigits})
const
factory
NumberFormatType.percent({int? decimalDigits})
const
factory
NumberFormatType.scientific()
const
factory
NumberFormatType.simpleCurrency({bool compact, String? name, int? decimalDigits})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(String locale) → NumberFormat
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

localeDefault → const NumberFormatType