localized_text_widget library
Classes
- DateFormatMessage
- JoinedMessage
- Concatenate the text of multiple Message instances together. If separator is not null, it's localized value will be inserted between each element.
-
LocalizationMessage<
T extends Object> -
Uses the instance of
Tin the given BuildContext to get a translated String. - Localized
- Creates a Text widget showing the translation of text for the current context's language.
- LocalizedText
- Message
- Getter for the translation of a String for the locale in a given BuildContext.
- NumberFormatMessage
- NumberFormatType
- StaticMessage
- Returns the value of text regardless of the current context's locale.