LocalizationMessage<T extends Object> class
abstract
Uses the instance of T in the given BuildContext to get a translated String.
- Inheritance
- Implemented types
Constructors
- LocalizationMessage()
-
const
- LocalizationMessage.getter(String getter(T localizations))
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
BuildContext context) → String -
inherited
-
getText(
BuildContext context, T localizations) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → String -
Retrieve the localized string for the given context
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited