Message class abstract
Getter for the translation of a String for the locale in a given BuildContext.
Constructors
- Message()
-
const
- Message.date(DateTime value, {String? pattern})
-
factory
- Message.fallback(String? text, Message fallback)
-
If the given
textis null, it falls back to the providedfallbackinstance.factory -
Message.joined(List<
Message> parts, {Message? separator}) -
Concatenate the text of multiple Message instances together.
If
separatoris not null, it's localized value will be inserted between each element.constfactory - Message.number(num value, {NumberFormatType pattern})
-
factory
- Message.static(String text)
-
Returns the value of
textregardless of the current locale.constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → String - Retrieve the localized string for the given context
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited