NumberFormatType class sealed
Constructors
- NumberFormatType.compact({bool long, bool explicitSign})
-
constfactory
- NumberFormatType.currency({bool compact, String? name, String? symbol, int? decimalDigits})
-
constfactory
- NumberFormatType.custom([String? pattern])
-
constfactory
- NumberFormatType.decimal({int? decimalDigits})
-
constfactory
- NumberFormatType.percent({int? decimalDigits})
-
constfactory
- NumberFormatType.scientific()
-
constfactory
- NumberFormatType.simpleCurrency({bool compact, String? name, int? decimalDigits})
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
String locale) → NumberFormat -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- localeDefault → const NumberFormatType