StaticMessage class final
Returns the value of text regardless of the current context's locale.
- Inheritance
- Implemented types
Constructors
- StaticMessage(String text)
-
const
Properties
Methods
-
get(
BuildContext context) → String -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext _) → String -
Retrieve the localized string for the given context
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited